@@ -182,7 +182,7 @@ class Adumo:
     @staticmethod
     def _process_response(response):
         response_dict = response.json()
-        logger.info(f'[Creditcard] {response=response_dict}')
+        logger.info(f"[Creditcard] {response_dict=}")
         status_code = response_dict.get("statusCode")
 
         if status_code and status_code != 200:
